import { RawData, WebSocket, WebSocketServer } from 'ws';
import { z } from 'zod';
import { PushFileParams, GetFileParams, DeleteFileParams, GetFileNamesParams, GetAllFilesParams, CalculateRamParams } from './messages';
export interface PromiseHolder<T = any> {
    resolve: (value?: T) => void;
    reject: (reason?: unknown) => void;
}
export interface MessageSchema<P = undefined, R extends z.ZodTypeAny = z.ZodTypeAny> {
    method: string;
    params?: P;
    validator?: R;
}
export interface WsManagerOptions {
    port: number;
    timeout?: number;
}
declare type Fn = (...args: any[]) => any;
declare type Promisable<T> = T | Promise<T>;
export declare class WsManager {
    options: Required<WsManagerOptions>;
    ws: WebSocket | undefined;
    wss: WebSocketServer;
    trackers: PromiseHolder[];
    nextId: number;
    unregisters: Fn[];
    constructor(options: WsManagerOptions);
    get connected(): boolean;
    _registerHandler(): void;
    onConnected(cb: (ws: WebSocket) => Promisable<Fn | void>): void;
    checkIfWssReused(): void;
    handleMessage(response: RawData): void;
    sendMessage<P = undefined, R extends z.ZodTypeAny = z.ZodTypeAny>(options: MessageSchema<P, R>): Promise<z.TypeOf<R>>;
    pushFile(params: PushFileParams): Promise<"OK">;
    getFile(params: GetFileParams): Promise<string>;
    deleteFile(params: DeleteFileParams): Promise<"OK">;
    getFileNames(params: GetFileNamesParams): Promise<string[]>;
    getAllFiles(params: GetAllFilesParams): Promise<{
        filename: string;
        content: string;
    }[]>;
    calculateRam(params: CalculateRamParams): Promise<number>;
    getDefinitionFile(): Promise<string>;
    close(): void;
}
export {};
